var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { memo, useCallback, useEffect, useRef, } from 'react';
import EditorJS from '@editorjs/editorjs';
import Paragraph from '@editorjs/paragraph';
import Header from '@editorjs/header';
const DEFAULT_ID = 'editorjs';
/**
 * EditorJs wraps editor.js in a React component and providing an API to be able
 * to interact with the editor.js instance.
 */
const EditorJs = (props) => {
    const { holderId: deprecatedId, holder: customHolderId, editorInstance, reinitializeOnPropsChange, children, tools } = props, otherProps = __rest(props, ["holderId", "holder", "editorInstance", "reinitializeOnPropsChange", "children", "tools"]);
    const instance = useRef(null);
    const holderId = deprecatedId || customHolderId || DEFAULT_ID;
    /**
     * initialise editorjs with default settings
     */
    const initEditor = useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!instance.current) {
            instance.current = new EditorJS(Object.assign({ tools: Object.assign({ paragraph: {
                        class: Paragraph,
                        inlineToolbar: true,
                    }, header: Header }, tools), holder: holderId }, otherProps));
        }
        // callback returns current editorjs instance once it is ready
        if (editorInstance) {
            yield instance.current.isReady;
            editorInstance(instance.current);
        }
    }), [editorInstance, holderId, otherProps, tools]);
    /**
     * destroy current editorjs instance
     */
    const destroyEditor = useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!instance.current) {
            return true;
        }
        yield instance.current.isReady;
        instance.current.destroy();
        instance.current = null;
        return true;
    }), [instance]);
    /**
     * initEditor on mount and destroy it on unmount
     */
    useEffect(() => {
        initEditor();
        return () => {
            destroyEditor();
        };
    }, []); // eslint-disable-line
    /**
     * when props change and reinitializeOnPropsChange is true, the component will
     * first destroy and then init EditorJS again.
     */
    useEffect(() => {
        const doEffect = () => __awaiter(void 0, void 0, void 0, function* () {
            if (!reinitializeOnPropsChange) {
                return;
            }
            yield destroyEditor();
            initEditor();
        });
        doEffect();
    }, [destroyEditor, initEditor, instance, reinitializeOnPropsChange]);
    return children || React.createElement("div", { id: holderId });
};
export default memo(EditorJs);
//# sourceMappingURL=editor.js.map